@@ -185,4 +185,11 @@ class HeatMap(Visualisation):
         params = kwargs
         params['matrix'] = matrix
         endpoint = "heatmap"
+        super().__init__(params, endpoint)
+
+class LineFight(Visualisation):
+    def __init__(self, samples, **kwargs):
+        params = kwargs
+        params['samples'] = samples
+        endpoint = "linefight"
         super().__init__(params, endpoint)
\ No newline at end of file
